summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/editor.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/koproperty/editor.h')
-rw-r--r--lib/koproperty/editor.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/koproperty/editor.h b/lib/koproperty/editor.h
index 677208de..c3ab0c2e 100644
--- a/lib/koproperty/editor.h
+++ b/lib/koproperty/editor.h
@@ -66,14 +66,14 @@ class KOPROPERTY_EXPORT Editor : public KListView
TQ_OBJECT
public:
/*! Creates an empty Editor with \a tqparent as tqparent widget.
If \a autoSync == true, properties values are automatically synced as
soon as editor contents change (eg the user types text, etc.)
and the values are written in the property set. Otherwise, property set
is updated only when selected item changes or user presses Enter key.
Each property can overwrite this if its autoSync() == 0 or 1.
*/
- Editor(TQWidget *tqparent=0, bool autoSync=true, const char *name=0);
+ Editor(TQWidget *parent=0, bool autoSync=true, const char *name=0);
virtual ~Editor();
@@ -160,7 +160,7 @@ class KOPROPERTY_EXPORT Editor : public KListView
void clearWidgetCache();
void fill();
- void addItem(const TQCString &name, EditorItem *tqparent);
+ void addItem(const TQCString &name, EditorItem *parent);
void showUndoButton( bool show );
@@ -66,14 +66,14 @@ class KOPROPERTY_EXPORT Editor : public KListView
TQ_OBJECT
public:
- /*! Creates an empty Editor with \a tqparent as tqparent widget.
+ /*! Creates an empty Editor with \a parent as parent widget.
If \a autoSync == true, properties values are automatically synced as
soon as editor contents change (eg the user types text, etc.)